legendopts: Translates options for legend into a list that can be passed to ggplot2
Description
This function takes the legend position and orientation, defined by the user and puts them into a list for ggplot2.
Usage
legendopts(legend_position = "right", legend_orientation = NULL)
Value
List of legend options for ggplot2.
Arguments
- legend_position
Default = "right".
- legend_orientation
Default = NULL.